@@ -68,7 +68,7 @@ class Scraper(object):
 
         try:
             if resolved_uri.scheme in ['http', 'https']:
-                instruction = json.loads(requests.get(resolved_uri).content)
+                instruction = json.loads(requests.get(resolved_uri).text)
             elif resolved_uri.scheme is '':
                 instruction = json.load(open(urlparse.urlunsplit(resolved_uri)))
             else:
